server_client_20141231_085104

### config2 : test_single_client_perf

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 1.79082512856 sec | 4.34895610809 sec

Error message: latency too high

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.51 | 0.13 | 0.078 | 0.1 | 0.15 | 0.18 | 0.2 | 0.37 | 0.061
qps | 74.00 | 50.50 | 27.00 | 50.50 | 62.25 | 69.30 | 71.65 | 73.53 | 23.50

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 508.86 | 508.86 | 508.86 | 508.86 | 508.86 | 508.86 | 508.86 | 508.86 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | qps | mean lt 7.0 | 50.5
server1-perf | latency | p50 lt 0.3 | 0.105
server1-perf | latency | mean lt 0.33 | 0.127732673267
server2-perf | qps | mean lt 7.0 | None
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
client1-perf | qps | mean lt 2.0 | 1.0
client1-perf | latency | p50 lt 22.0 | 508.859
client1-perf | latency | mean lt 35.0 | 508.859
client2-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None